@@ -42,7 +42,3 @@ def test_procgen():
 
     for i, env_id in enumerate(mujoco_env_ids):
         test_env(env_id)
-
-
-if __name__ == "__main__":
-    test_procgen()
